Learn R Programming

lqmm (version 1.01)

lqm.fit.gs: Quantile Regression Fitting by Gradient Search

Description

This function controls the arguments to be passed to routines written in C for LQM estimation. The optimization algorithm is based on the gradient of the Laplace log--likelihood (Bottai, Orsini and Geraci, 2011).

Usage

lqm.fit.gs(theta, x, y, weights, iota, control)

Arguments

theta
starting values for the regression coefficients.
x
the model matrix.
y
the model response.
weights
the weights used in the fitting process.
iota
the quantile to be estimated.
control
list of control parameters used for optimization (see lqmControl).

Value

  • An object of class list containing the following components:
  • thetaa vector of coefficients.
  • scalethe scale parameter.
  • logLikthe log--likelihood.
  • optnumber of iterations when the estimation algorithm stopped.
  • .

Details

See argument fit in lqm for generating a list of arguments to be called by this function.

References

Bottai M, Orsini N and Geraci M (2011). A Gradient Search Maximization Algorithm for Laplace Likelihood. Unpublished manuscript.

See Also

lqm

Examples

Run this code
set.seed(12356)
n <- 200
p <- 1:3/4
test <- data.frame(x = runif(n,0,1))
test$y <- 30 + test$x + rnorm(n)
lqm.ls <- lqm(y ~ x, data = test, iota = p, fit = FALSE)

do.call("lqm.fit.gs", lqm.ls)

Run the code above in your browser using DataLab