Fit quantile regression models for independent and hierarchical data
| Package: | lqmm |
| Type: | Package |
| Version: | 1.5.3 |
| Date: | 2016-01-28 |
| License: | GPL (>=2) |
| LazyLoad: | yes |
Geraci M and Bottai M (2007). Quantile regression for longitudinal data using the asymmetric Laplace distribution. Biostatistics 8(1), 140--154.
Geraci M and Bottai M (2014). Linear quantile mixed models. Statistics and Computing, 24(3), 461--479.
Geraci M. (2014) Linear quantile mixed models: The lqmm package for Laplace quantile regression, Journal of Statistical Software, 57(13), 1--29.