Learn R Programming

lqmm (version 1.04)

meanAL: Functions for Asymmetric Laplace Distribution Parameters

Description

Accessory functions.

Usage

meanAL(mu, sigma, tau)
varAL(sigma, tau)
invvarAL(x, tau)

Arguments

mu
location parameter.
sigma
scale parameter.
tau
skewness parameter.
x
numeric value.

Details

meanAL computes the mean of an asymmetric Laplace with parameters mu, sigma and tau. varAL computes the variance of an asymmetric Laplace with parameters sigma and tau. invvarAL computes the scale parameter of an asymmetric Laplace with parameter tau and variance x.

References

Yu K and Zhang J (2005). A three-parameter asymmetric Laplace distribution and its extension. Communications in Statistics-Theory and Methods 34, 1867--1879.

See Also

dal, mleAL