Learn R Programming

lqmm (version 1.01)

predict.lqm: Predictions from an lqm Object

Description

This function computes predictions based on fitted linear quantile model.

Usage

## S3 method for class 'lqm':
predict(object, newdata, interval = FALSE,
	level = 0.95, na.action = na.pass, ...)

Arguments

object
an lqm object.
newdata
an optional data frame in which to look for variables with which to predict. If omitted, the fitted values are used.
interval
logical flag. If TRUE, bootstrap percentile intervals for predictions are provided.
level
confidence level.
na.action
function determining what should be done with missing values in newdata. The default is to predict NA.
...
further arguments passed to boot.lqm.

Value

  • a vector or a matrix or an array of predictions.

See Also

residuals.lqm, lqm, coef.lqmm, boot.lqm