Learn R Programming

lqmm (version 1.01)

predict.lqmm: Predictions from an lqmm Object

Description

The predictions at level 0 correspond to population predictions (based only on the fixed effects estimates). The predictions at level 1 are obtained by adding the best linear predictions of the random effects to the predictions at level 0.

Usage

## S3 method for class 'lqmm':
predict(object, level = 0, ...)

Arguments

object
an lqmm object.
level
an optional integer vector giving the level of grouping to be used in obtaining the predictions. Level zero corresponds to the population predictions.
...
not used.

Value

  • a matrix of predictions.

References

Geraci M and Bottai M (1 June 2011). Linear Quantile Mixed Models. Unpublished manuscript.

See Also

lqmm, raneff.lqmm, coef.lqmm