Learn R Programming

lqmm (version 1.03)

raneff.lqmm: Random Effects

Description

This function computes random effects for a linear quantile mixed model.

Usage

raneff.lqmm(object)

Arguments

object
an object of class lqmm.

Value

  • a data frame or a list of data frames of predicted random effects.

Details

The prediction of the random effects is done via estimated best linear prediction. See references for details.

References

Geraci M and Bottai M (2013). Linear quantile mixed models. Statistics and Computing, doi: 10.1007/s11222-013-9381-9.

See Also

lqmm, coef.lqmm