Learn R Programming

lqmm (version 1.02)

residuals.lqmm: Residuals from an lqmm Object

Description

The residuals at level 0 correspond to population residuals (based only on the fixed effects estimates). The residuals at level 1 are obtained by adding the best linear predictions of the random effects to the predictions at level 0 and the subtracting these from the model response.

Usage

## S3 method for class 'lqmm':
residuals(object, level = 0, ...)

Arguments

object
an lqmm object.
level
an optional integer vector giving the level of grouping to be used in obtaining the predictions. Level zero corresponds to the population residuals.
...
not used.

Value

  • a matrix of residuals.

References

Geraci M and Bottai M (1 June 2011). Linear Quantile Mixed Models. Unpublished manuscript.

See Also

lqmm, predict.lqmm, coef.lqmm, raneff.lqmm,