Learn R Programming

lqmm (version 1.03)

summary.boot.lqmm: Summary for a boot.lqmm Object

Description

This function gives a summary of a botstrapped lqmm object

Usage

## S3 method for class 'boot.lqmm':
summary(object, alpha = 0.05, digits = max(3, getOption("digits") - 3), ...)

Arguments

object
an object of class lqmm.
alpha
numeric value for the interval confidence level (1-alpha).
digits
a non-null value for digits specifies the minimum number of significant digits to be printed in values.
...
not used.

References

Geraci M and Bottai M (2013). Linear quantile mixed models. Statistics and Computing, doi: 10.1007/s11222-013-9381-9.

See Also

boot.lqmm, lqmm,