Learn R Programming

lqmm (version 1.01)

summary.lqm: Summary for an lqm Object

Description

Summary method for class lqm.

Usage

## S3 method for class 'lqm':
summary(object, alpha = 0.05, covariance = FALSE, ...)

Arguments

object
an object of class lqm
alpha
significance level.
covariance
logical flag. If TRUE the bootstrapped variance-covariance matrix is provided.
...
see boot.lqm for additional arguments.

Value

  • an object of class summary.lqm. The function summary.lqm computes and returns a list of summary statistics of the fitted linear quantile mixed model given in object, using the components (list elements) from its argument, plus
  • Covthe covariance matrix obtained from the bootstrapped estimates (if covariance = TRUE).
  • tTablea matrix with estimates, standard errors, etc.

Details

print.summary.lqm formats the coefficients, standard errors, etc. and additionally gives `significance stars'.

See Also

print.summary.lqm lqm

Examples

Run this code
set.seed(12356)
n <- 200
p <- 1:3/4
test <- data.frame(x = runif(n,0,1))
test$y <- 30 + test$x + rnorm(n)
fit.lqm <- lqm(y ~ x, data = test, iota = p)
summary(fit.lqm, R = 50)

Run the code above in your browser using DataLab