Learn R Programming

lqmm (version 1.02)

summary.lqmm: Summary for an lqmm Object

Description

Summary method for class lqmm.

Usage

## S3 method for class 'lqmm':
summary(object, method = "boot", alpha = 0.05, covariance = FALSE, ...)

Arguments

object
an object of class lqmm.
method
specifies the method used to compute standard errors. Currently, only the bootstrap method ("boot") is available.
alpha
significance level.
covariance
logical flag. If TRUE the bootstrapped variance-covariance matrix is provided.
...
see boot.lqmm for additional arguments.

Value

  • an object of class summary.lqmm. The function summary.lqmm computes and returns a list of summary statistics of the fitted linear quantile mixed model given in object, using the components (list elements) from its argument, plus
  • Covthe covariance matrix obtained from the bootstrapped estimates (if covariance = TRUE).
  • tTablea matrix with estimates, standard errors, etc.
  • Bthe matrix of all bootstrapped parameters.

Details

print.summary.lqmm formats the coefficients, standard errors, etc. and additionally gives `significance stars'.

See Also

print.summary.lqmm lqmm

Examples

Run this code
data(Orthodont)
fitOi.lqmm <- lqmm(distance ~ age, random = ~ 1, group = Subject,
	iota = c(0.1,0.5,0.9), data = Orthodont)
summary(fitOi.lqmm)

Run the code above in your browser using DataLab