logical flag. If TRUE the estimated parameters in object are used as starting values in lqm.fit.gs applied to bootstrap samples. Otherwise starting values are based on
Value
An object of class boot.lqm is a data frame with R rows and npars columns containing the bootstrap estimates of theta. If object contains results for multiple quantiles, boot.lqm returns an array of dimension c(R,npars,nt), where nt is the length of tau.
The following attributes are available:
tauindex of the quantile(s).
estimatedthe estimated parameter as given by object.
Rnumber of bootstrap replications.
seedthe random number generator seed used to produce the bootstrap sample.
nparstotal numer of parameters.
rdfthe number of residual degrees of freedom.
indicesthe bootstrap sample of independent data units.