boot.lqm: Bootstrapping Linear Quantile Models
Description
This function is used to obtain a bootstrap sample of a fitted LQM.Usage
boot.lqm(object, R = 50, seed = round(runif(1, 1, 10000)), startQR = FALSE)
Arguments
object
an object of class "lqm". R
number of bootstrap replications.
seed
optional random generator seed.
startQR
logical flag. If TRUE the estimated parameters in object are used as starting values in lqm.fit.gs applied to bootstrap samples. Otherwise starting values are based on Value
- an object of class "boot.lqm".