logical flag. If TRUE the estimated parameters in object are used as starting values in lqmm.fit applied to bootstrap samples. Otherwise starting values are based on lm.
Value
An object of class boot.lqmm is a data frame with R rows and npars columns containing the bootstrap estimates of theta_x, theta_z, and scale. If object contains results for multiple quantiles, boot.lqmm returns an array of dimension c(R,npars,nt), where nt is the length of tau.
The elements of theta_z are labelled with reStruct. See function covHandling and the example below on how to derive the variance-covariance matrix of the random effects starting from theta_z. The following attributes are available:
tauindex of the quantile(s).
estimatedthe estimated parameter as given by object.
Rnumber of bootstrap replications.
seedthe random number generator seed used to produce the bootstrap sample.
nnlabels of the fixed effects.
nparstotal numer of parameters.
indicesthe bootstrap sample of independent data units.
References
Geraci M and Bottai M (2013). Linear quantile mixed models. Statistics and Computing, doi: 10.1007/s11222-013-9381-9.