boot.lqmm: Bootstrapping Linear Quantile Mixed Models
Description
This function is used to obtain a bootstrap sample of a fitted LQMM.Usage
boot.lqmm(object, R = 50, seed = round(runif(1, 1, 10000)), startQR = FALSE)
Arguments
object
an object of class "lqmm". R
number of bootstrap replications.
seed
optional random generator seed.
startQR
logical flag. If TRUE the estimated parameters in object are used as starting values in lqmm.fit applied to bootstrap samples. Otherwise starting values are based on lm. Value
- an object of class "boot.lqmm".