Learn R Programming

lqmm (version 1.0)

extractBoot.lqmm: Extract Fixed and Random Bootstrapped Parameters

Description

This function extracts the fixed and random components of bootstrapped estimates of an lqmm object.

Usage

extractBoot.lqmm(object, which = "fixed")

Arguments

object
an object of class boot.lqmm.
which
character indicating whether "fixed" or "random" parameters.

Value

  • a matrix of bootstrapped estimates.

Details

The "random" parameters refer to the "raw" parameters of the variance-covariance matrix of the random effects as returned by lqmm.fit.gs and lqmm.fit.df.

See Also

boot.lqmm, lqmm.fit.gs, lqmm.fit.df