Usage
lqm.counts(formula, data, weights = NULL, offset = NULL, contrasts = NULL,
tau = 0.5, M = 50, zeta = 1e-05, B = 0.999, cn = NULL, alpha = 0.05,
control = list())
Arguments
formula
an object of class formula: a symbolic description of the model to be fitted. data
an optional data frame, list or environment (or object coercible by as.data.frame to a data frame) containing the variables in the model. If not found in data, the variables are taken from environment(formula), typically the environment from which lqm is
weights
an optional vector of weights to be used in the fitting process.
offset
an optional offset to be included in the model frame.
tau
quantile to be estimated.
M
number of dithered samples.
zeta
small constant (see References).
B
right boundary for uniform random noise U[0,B] to be added to the response variable (see References).
cn
small constant to be passed to F.lqm (see References). control
list of control parameters of the fitting process. See lqmControl.