lqm.fit.gs: Quantile Regression Fitting by Gradient Search
Description
This function controls the arguments to be passed to routines written in C for LQM estimation. The optimization algorithm is based on the gradient of the Laplace log--likelihood (Bottai, Orsini and Geraci, 2011).
Usage
lqm.fit.gs(theta, x, y, weights, iota, control)
Arguments
theta
starting values for the regression coefficients.
x
the model matrix.
y
the model response.
weights
the weights used in the fitting process.
iota
the quantile to be estimated.
control
list of control parameters used for optimization (see lqmControl).
Value
An object of class list containing the following components:
thetaa vector of coefficients.
scalethe scale parameter.
logLikthe log--likelihood.
optnumber of iterations when the estimation algorithm stopped.
.
Details
See argument fit in lqm for generating a list of arguments to be called by this function.
References
Bottai M, Orsini N and Geraci M (2011). A Gradient Search Maximization Algorithm for Laplace Likelihood. Unpublished manuscript.