lqmm-package: Linear Quantile Models and Linear Quantile Mixed Models
Description
Fit quantile regression models for independent and hierarchical dataDetails
ll{
Package: lqmm
Type: Package
Version: 1.04
Date: 2014-01-09
License: GPL (>=2)
LazyLoad: yes
}References
Geraci M and Bottai M (2007). Quantile regression for longitudinal data using the asymmetric Laplace distribution. Biostatistics 8(1), 140--154.
Geraci M and Bottai M (2013). Linear quantile mixed models. Statistics and Computing, doi: 10.1007/s11222-013-9381-9.
Geraci M. (2014) Linear quantile mixed models: The lqmm package for Laplace quantile regression, Journal of Statistical Software (in press).