lqmm-package: Linear Quantile Models and Linear Quantile Mixed Models
Description
Fit quantile regression models for independent and hierarchical dataDetails
ll{
Package: lqmm
Type: Package
Version: 1.1
Date: 2012-05-30
License: GPL (>=3)
LazyLoad: yes
}References
Geraci M and Bottai M (2007). Quantile regression for longitudinal data using the asymmetric Laplace distribution. Biostatistics 8(1), 140--154.
Geraci M and Bottai M (1 June 2011). Linear Quantile Mixed Models. Unpublished manuscript.