raneff.lqmm: Random Effects
Description
This function computes random effects for a linear quantile mixed model.Value
- a data frame or a list of data frames of predicted random effects.
Details
The prediction of the random effects is done via estimated best linear prediction. See references for details.References
Geraci M and Bottai M (1 June 2011). Linear Quantile Mixed Models. Unpublished manuscript.