an object of class summary.lqm. The function summary.lqm computes and returns a list of summary statistics of the fitted linear quantile mixed model given in object, using the components (list elements) from its argument, plus
Covthe covariance matrix obtained from the bootstrapped estimates (if covariance = TRUE).
tTablea matrix with estimates, standard errors, etc.
Details
print.summary.lqm formats the coefficients, standard errors, etc. and additionally gives `significance stars'.