an object of class summary.lqmm. The function summary.lqmm computes and returns a list of summary statistics of the fitted linear quantile mixed model given in object, using the components (list elements) from its argument, plus
Covthe covariance matrix obtained from the bootstrapped estimates (if covariance = TRUE).
tTablea matrix with estimates, standard errors, etc.
Bthe matrix of all bootstrapped parameters.
Details
print.summary.lqmm formats the coefficients, standard errors, etc. and additionally gives `significance stars'.